```
Usage: vcd gateway services static-route update [OPTIONS] <gateway name> <ip>

Options:
  -n, --network <ip>    IP address of network in CIDR format
  --next-hop <ip>       IP address of the next hop
  --mtu <mtu>           MTU of static route
  --desc <description>  description
  -v, --vnic <vnic>     interface of gateway
  -h, --help            Show this message and exit.

```
